@@ -14,12 +14,12 @@ import os.path
 import tempfile
 from ._compat import to_unicode, pickle
 
-__version__ = '0.2'
+__version__ = '0.3'
 __author__ = 'Hsiaoming Yang <me@lepture.com>'
 
 __all__ = [
     'is_asdf', 'is_by_step', 'is_common_password',
-    'safety', 'Strength',
+    'check', 'Strength',
 ]
 
 log = logging.getLogger('safe')
@@ -31,9 +31,10 @@ MARKS = re.compile(r'[^0-9a-zA-Z]')
 
 
 def _load_words():
+    filename = 'safe-%s.words.cache' % __version__
     _cache_file = os.environ.get(
         'PYTHON_SAFE_WORDS_CACHE',
-        os.path.join(tempfile.gettempdir(), 'password.words.cache'),
+        os.path.join(tempfile.gettempdir(), filename),
     )
 
     if os.path.exists(_cache_file):
@@ -138,7 +139,7 @@ class Strength(object):
         return self.valid
 
 
-def safety(raw, length=4, freq=0):
+def check(raw, length=4, freq=0):
     """Check the safety level of the password.
 
     :param raw: raw text password.
@@ -176,3 +177,7 @@ def safety(raw, length=4, freq=0):
         return Strength(True, 'strong', 'password is perfect')
 
     return Strength(True, 'medium', 'password is good enough')
+
+
+def safety(raw, length=4, freq=0):
+    return check(raw, length=4, freq=0)
